'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var cleanDeep = require('clean-deep');
var deepObjectDiff = require('deep-object-diff');
var omitDeep = require('omit-deep-lodash');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var cleanDeep__default = /*#__PURE__*/_interopDefaultLegacy(cleanDeep);
var omitDeep__default = /*#__PURE__*/_interopDefaultLegacy(omitDeep);

var OMIT_PROPERTIES = ['__typename', 'id', 'updated_at', 'created_at'];
function cleanGqlInput(entity, omit) {
  if (omit === void 0) {
    omit = OMIT_PROPERTIES;
  }

  return sortObject( // cleanDeep( Removes empty objects, arrays, empty strings, NaN, null and undefined values from objects.
  omitDeep__default["default"].apply(void 0, [// removes unwanted properties
  entity].concat(omit)));
}
function cleanDiff(originalObj, updatedObj) {
  return cleanDeep__default["default"](deepObjectDiff.diff(cleanGqlInput(originalObj), cleanGqlInput(updatedObj)), {
    emptyArrays: true,
    emptyObjects: true,
    emptyStrings: false
  });
} // from https://github.com/IndigoUnited/js-deep-sort-object/blob/master/index.js

function isPlainObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]';
}

function defaultSortFn(a, b) {
  return a.localeCompare(b);
}

function sortObject(src, comparator) {
  if (Array.isArray(src)) {
    return src.map(function (item) {
      return sortObject(item, comparator);
    });
  }

  if (isPlainObject(src)) {
    var out = {};
    Object.keys(src).sort(comparator || defaultSortFn).forEach(function (key) {
      out[key] = sortObject(src[key], comparator);
    });
    return out;
  }

  return src;
}

exports.OMIT_PROPERTIES = OMIT_PROPERTIES;
exports.cleanDiff = cleanDiff;
exports.cleanGqlInput = cleanGqlInput;
exports.sortObject = sortObject;
//# sourceMappingURL=graphql-clean-diff.cjs.development.js.map
